------------------------------------------------------
-- ColorBar v1.0
-- By Lockdown Media 3D - http://3d.ldm.no
-- Inspired by joegunn3d's color bar
------------------------------------------------------

macroScript ColorBar category: "LDM3D"
tooltip: "Launch Color Bar" buttontext:"Color Bar" autoUndoEnabled:false
icon:#("ColorBar", 1) -- Icon from the Default Max library
(
	--local var_BarIsOpen = false --initialize to false (closed)
	
	-- Register the rollouts
	global	roll_colorBar
	local		roll_colorBarSettings
	
	-- Register local variables
	local		var_wireANDtooltip	= "Click: Apply wirecolor to all selected objects\nAlt+Click: Generate random color"
	local		var_dialogHeight		= 40
	local		var_dialogWidth		= 450
	
	
	-- ======================================================================================
	-- Building the INI system / Reset color function
	-- ======================================================================================
	
	-- Setting path to the INI file
	local var_INIpath					= getdir #plugcfg + "\\LDM3D_ColorBar.ini"													-- Change so we use #plugcfg instead of #scripts dir (allow per-user settings)?
	--local var_INIpath					= getdir #plugcfg + "\\AwsomeScript\\ColorBar.ini"													-- Change so we use #plugcfg instead of #scripts dir (allow per-user settings)?
	
	-- Function used for default and reset color scemes
	function fn_resetColors var_resetBlanks:false =
	(
		local roll_progressbar																													-- Register the progressbar rollout so we can destroy it later

		-- Register the rollout containing the progressbar
		rollout roll_progressbar "Resetting colors" width:200
		(
			label lbl_pbar "Resetting color schemes..."
			progressbar pbar color:green
		)
		createdialog roll_progressbar
		
		
		for i = 1 to 10 do																														-- !! INCREASE IF MORE COLORPICKERS IS ADDED !! --
		(
			if var_resetBlanks == true then
			(
				roll_progressbar.pbar.value = 100*i/99																					-- Checks if we need to divide progress % for 10 or 99 operations
				roll_progressbar.lbl_pbar.text = "[" + (i as string) + "/10] Resetting color schemes..."						-- Alter update text to show current progress if run more then 1 time
			)
			else
				roll_progressbar.pbar.value = 100*i/10																					-- Checks if we need to divide progress % for 10 or 99 operations
			
			
			
			local var_colorPickerNr = "cp_" + (i as string)
			
			-- Color Memmo and Testing:
				--	(((255/10)*i) as string)				Dark to light		Example: local var_NewColor14 = "(color 255 " + (((255/10)*i) as string) + " 255)"
				--	((255-((255/10)*i)) as string)		Light to dark		Example: local var_NewColor14 = "(color 255 " + ((255-((255/10)*i)) as string) + " 255)"
				-- 	local var_NewColor15 = "(color 255 " + ((126+((255/i)/2)) as string) + " " + ((255/i) as string) + ")"
				--	local var_NewColor8	 = "(color " + ((255/i) as string) + " " + ((126/i) as string) + " 0)"
			
			-- Red
			local var_NewColor1	= "(color " + ((255-((255/10)*i)) as string) + " 0 0)"
			local var_NewColor9	= "(color " + "255 " + ((255-((255/10)*i)) as string) + " " +((255-((255/10)*i)) as string) + ")"
			
			-- Green
			local var_NewColor2	= "(color " + "0 " +((255-((255/10)*i)) as string) + " 0)"
			local var_NewColor10	= "(color " + ((255-((255/10)*i)) as string) + " 255 " + ((255-((255/10)*i)) as string) + ")"
			
			-- Blue
			local var_NewColor3	= "(color " + "0 0 " + ((255-((255/10)*i)) as string) + ")"
			local var_NewColor11	= "(color " + ((255-((255/10)*i)) as string) + " " + ((255-((255/10)*i)) as string) + " 255)"
			
			-- Black / White
			local var_NewColor4	= "(color " + ((255-((255/10)*i)) as string) + " " + ((255-((255/10)*i)) as string) + " " + ((255-((255/10)*i)) as string) + ")"
			
			-- Yellow
			local var_NewColor5	= "(color " + ((255-((255/10)*i)) as string) + " " + ((255-((255/10)*i)) as string) + " 0" + ")"
			local var_NewColor12	= "(color 255 255 " + ((255-((255/10)*i)) as string) +")"
			
			-- Cyan
			local var_NewColor6	= "(color " + "0 " + ((255-((255/10)*i)) as string) + " " + ((255-((255/10)*i)) as string) + ")"
			local var_NewColor13	= "(color " + ((255-((255/10)*i)) as string) + " 255 255)"
			
			-- Pink / Purple
			local var_NewColor7	= "(color " + ((255-((255/10)*i)) as string) + " 0 " + ((255-((255/10)*i)) as string) + ")"
			local var_NewColor14	= "(color 255 " + ((255-((255/10)*i)) as string) + " 255)"
			
			-- Orange / Brown
			local var_NewColor8	= "(color " + ((255-((255/10)*i)) as string) + " " + ((127-((127/10)*i)) as string) + " 0)"
			local var_NewColor15	= "(color 255 " + ((255-((127/10)*i)) as string)+ " " + ((255-((255/10)*i)) as string) + ")"
			
			-- Write all the settings to the INI-file
			setIniSetting var_INIpath "Preset1"		var_colorPickerNr var_NewColor1
			setIniSetting var_INIpath "Preset2"		var_colorPickerNr var_NewColor2
			setIniSetting var_INIpath "Preset3"		var_colorPickerNr var_NewColor3
			setIniSetting var_INIpath "Preset4"		var_colorPickerNr var_NewColor4
			setIniSetting var_INIpath "Preset5"		var_colorPickerNr var_NewColor5			
			setIniSetting var_INIpath "Preset6"		var_colorPickerNr var_NewColor6
			setIniSetting var_INIpath "Preset7"		var_colorPickerNr var_NewColor7
			setIniSetting var_INIpath "Preset8"		var_colorPickerNr var_NewColor8
			setIniSetting var_INIpath "Preset9"		var_colorPickerNr var_NewColor9
			setIniSetting var_INIpath "Preset10"	var_colorPickerNr var_NewColor10
			setIniSetting var_INIpath "Preset11"	var_colorPickerNr var_NewColor11
			setIniSetting var_INIpath "Preset12"	var_colorPickerNr var_NewColor12
			setIniSetting var_INIpath "Preset13"	var_colorPickerNr var_NewColor13
			setIniSetting var_INIpath "Preset14"	var_colorPickerNr var_NewColor14
			setIniSetting var_INIpath "Preset15"	var_colorPickerNr var_NewColor15
			
			
			if var_resetBlanks == true do																									-- Only reset all files if it's been requested from the function
			(
				-- Write all blanks to the INI-file
				for i = 16 to 99 do
				(
					setIniSetting var_INIpath ("Preset" + i as string) var_colorPickerNr "(color 255 255 255)"				-- Save all presets from 16 and above as white
					roll_progressbar.pbar.value = 100*i/99																				-- Update the progressbar
				)
			)
		)
		try (destroydialog roll_progressbar) catch()																						-- Destroy the progressbar after reset it done
	) -- end fn_resetColors

	
	-- Creating the file if it don't already exsist
	if (doesFileExist(var_INIpath) == false) then																						-- Se if the INI-file exsist
	(
		createFile var_INIpath																													-- If not, create it
		fn_resetColors var_resetBlanks:true																								-- Run a 'reset' so we will write all colors to the ini-file
		
		-- Applying temp values in the variables until it have been written to the ini-file
		local var_LastPos			= [-1,-1]
		local var_DockState			= cui_floatable
		local var_ActiveSwatch	= 1
		local var_LoadOnStartup	= setIniSetting var_INIpath "Dialog" "LoadOnStartup" "true"
	)
	else
	(
		-- Prepares easy access to the settings
		local var_LastPos			= execute (getIniSetting var_INIpath "Dialog" "Position")
		local var_DockState			= (getIniSetting var_INIpath "Dialog" "DockState")
		local var_ActiveSwatch	= (getIniSetting var_INIpath "Dialog" "ActiveSwatch")
	)
	

	-- ======================================================================================
	-- Destroy duplicate rollouts when starting. Done so late so we can save the settings for later
	-- ======================================================================================

	-- Try to unregister the dialog so we dont get several open
	try (cui.unRegisterDialogBar roll_colorBar)	catch()
	try (destroydialog roll_colorBar)					catch()

	
	-- ======================================================================================
	-- Functions
	-- ======================================================================================
	
	
	-- Function that saves the colors to an INI as they are changed
	function fn_SavePreset var_colorPickerNr var_NewColor =
	(
		local var_activePreset = "Preset" + (roll_colorBar.spn_preset.value as string)										-- Build the save-string that's used for the preset
		
		setIniSetting var_INIpath var_activePreset var_colorPickerNr (var_NewColor as string)								-- Save the color to the INI-file
	) -- end fn_SavePreset
	
	
	-- Function that loads the colors from an INI back to the colorpickers when the preset is changed
	function fn_LoadPreset var_CurrentPreset =
	(
		local var_activePreset = "Preset" + (var_CurrentPreset as string)														-- Build the load-string that's used for the preset
		setIniSetting var_INIpath "Dialog" "ActiveSwatch" (var_CurrentPreset as string)
		
		for i = 1 to 10 do																														-- !! INCREASE IF MORE COLORPICKERS IS ADDED !! --
		(
			local var_loadColor = (getIniSetting var_INIpath var_activePreset ("cp_" + i as string))						-- Load the color from the INI-file
				
			if var_loadColor != "" then																										-- We need to make sure there is a color to change so we don't get an error!
			(
				local var_ChangeColor = "roll_colorBar.cp_" + (i as string) + ".color = " + var_loadColor					-- Build the string used for changing the colorpicker color
				execute var_ChangeColor																										-- Execute the variable so we can use variables to change the color value in menu names
			)
			else																																		-- If there is no color defined for the picker, default it to white
			(
				local var_ChangeColor = "roll_colorBar.cp_" + (i as string) + ".color = (color 255 255 255)"				-- Build the string used for changing the colorpicker color
				execute var_ChangeColor																										-- Execute the variable so we can use variables to change the color value in menu names
			)
		)
	) -- end fn_LoadPreset
	
	
	-- Function that applies the wire color, and randomizes it if requested
	function fn_WireAndRandomColor var_colorPickerNr =
	(
		if keyboard.altpressed then																											-- If alt was pressed, generate a randomized color
		(
			local var_random1 = ((random 0 255) as string) + " "
			local var_random2 = ((random 0 255) as string) + " "
			local var_random3 = ((random 0 255) as string)
			local var_randomColor = "(color " + var_random1 + var_random2 + var_random3 + ")"						-- Build the randomized color
			
			local var_ChangeColor = "roll_colorBar." + var_colorPickerNr + ".color = " + var_randomColor				-- Build the string used for changing the colorpicker color
			execute var_ChangeColor																											-- Execute the variable so we can use variables to change the color value in menu names
			
			fn_SavePreset var_colorPickerNr var_randomColor																			-- Run the function that saves the new color
		)
		else
		(
			if selection.count > 0 do																											-- Make sure there is a selection to apply wirecolor to
			(
				local var_ChangeColor = "roll_colorBar." + var_colorPickerNr + ".color"											-- Build the string used for getting the colorpicker color
				try (selection.wirecolor = execute var_ChangeColor) catch()														-- Trap errors from objects that dont have wirecolor
			)
		)
	) -- end fn_WireAndRandomColor
	
	
	-- ======================================================================================
	-- Settings function & rollout
	-- ======================================================================================
	
	
	-- function that randomizes all colors, and spawn settings menu
	function fn_colorBarSettings =
	(
		-- Load settings used in the rollout
		var_LoadOnStartup	= (getIniSetting var_INIpath "Dialog" "LoadOnStartup")
		
		-- Run button pressed action
		if keyboard.altpressed then																											-- Randomize all colors if alt was pressed
		(
			for i = 1 to 10 do																													-- !! INCREASE IF MORE COLORPICKERS IS ADDED !! --
			(
				local var_colorPickerNr = "cp_" + (i as string)																			-- Build name for all colorpickers
				fn_WireAndRandomColor var_colorPickerNr																				-- Randomize the colorpickers
			)
		)
		else if keyboard.controlPressed then
		(
			shellLaunch @"http://www.colorschemedesigner.com" ""
		)
		else
		(
			rollout roll_colorBarSettings "Color Bar Settings"
			(
				group "Settings"
				(
					checkbox		chkbox_loadOnStart		"Load on startup" checked:(var_LoadOnStartup as booleanClass) enabled:true tooltip:"Not yet implemented!" on chkbox_loadOnStart changed value do
						setIniSetting var_INIpath "Dialog" "LoadOnStartup" (chkbox_loadOnStart.state as string)
					checkbox		chkbox_startDocked		"Start Docked" checked:false enabled:false tooltip:"Not yet implemented!"
					radiobuttons	rbtn_barDockPosition1	columns:2	labels:#("Left","Right")		enabled:roll_colorBarSettings.chkbox_startDocked.checked	visible:false
					radiobuttons	rbtn_barDockPosition2	columns:2	labels:#("Top","Bottom")	enabled:roll_colorBarSettings.chkbox_startDocked.checked	visible:true	pos:rbtn_barDockPosition1.pos 
				)
				
				group "Startup Orientation"
				(
					radiobuttons rbtn_barPosition columns:2 labels:#("Horizontal","Vertical") tooltip:"Decides if the colorbar will open in a vertical or horizontal position" enabled:false
				)
				
				group "Import / Export"
				(
					button	btn_import	"Import Settings"	tooltip:"Import an INI-file containing settings and color swatches.\n\nWARNING: This will erase all current settings and color swatches!" across:2 
					button	btn_export	"Export Settings"		tooltip:"Export all current settings and color swatches.\nThis file can be used later on to restore the settings, or can be imported on another installation."
				)
				
				group "Reset"
				(
					button			btn_reset			"Reset Color Schemes"
					checkbox	chkbox_resetAll	"Only preset-swatches (1-15)"	checked:true
				)
				
				group "About"
				(
					label			lbl_name			"Color Bar v1.0"					align:#left
					label			lbl_madeBy		"By Lockdown Media 3D"		align:#left
					hyperlink	link_madeBy	"http://3d.ldm.no"				address:"http://3d.ldm.no"
				)
				
				-- Enable / disable radiobuttons for the dock-positions based on whether or not 'start docked' is enabled or disabled
				on chkbox_startDocked changed state do
				(
					roll_colorBarSettings.rbtn_barDockPosition1.enabled = not roll_colorBarSettings.rbtn_barDockPosition1.enabled
					roll_colorBarSettings.rbtn_barDockPosition2.enabled = not roll_colorBarSettings.rbtn_barDockPosition2.enabled
				)
				
				
				-- Change between top/bottom and left/right on the dockposition based on the horizontal/vertical setting
				on rbtn_barPosition changed state do
				(
					if rbtn_barPosition.state == 1 do																						-- If dockposition is horizontal, enable left/right and hide top/bottom
					(
						roll_colorBarSettings.rbtn_barDockPosition1.visible = false
						roll_colorBarSettings.rbtn_barDockPosition2.visible = true
					)
					if rbtn_barPosition.state == 2 do																						-- If dockposition is vertican, enable top/bottom and hide left/right
					(
						roll_colorBarSettings.rbtn_barDockPosition1.visible = true
						roll_colorBarSettings.rbtn_barDockPosition2.visible = false
					)
				)
				
				
				-- Run a color swatch reset (1-15 default, all if checkbox is unchecked)
				 on btn_reset pressed do
				(
					if roll_colorBarSettings.chkbox_resetAll.checked == true then
						fn_resetColors()																											-- Run function for reset for preset 1-15
					else
						fn_resetColors var_resetBlanks:true																				-- Run function for reset with the optinal value that resets ALL presets, not just the color schemes
					fn_LoadPreset roll_colorBar.spn_preset.value																			-- Reload the current color scheme to apply the change in colors
				)
				
				
				-- Export current settings to a new INI-file
				on btn_import pressed do
				(
					local f = getOpenFileName caption:"Select the file you want to import:" filename:var_INIpath types:"INI-file (*.ini)|*.ini|All files (*.*)|*.*|"
					if f != undefined do																											-- Make sure the user didn't press cancel
					(
						if queryBox "You are about to import a new configuration-file.\nAll current settings and color swatches will be lost, and it is therefore recommended that you take a copy of your settings before proceeding!\n\nAre you sure you want to continue?" title:"Color Bar: Import Settings" beep:true do
						(
							deleteFile var_INIpath																								-- Delete current copy of the file
							copyFile f var_INIpath																								-- Copy over the new version
							fn_LoadPreset roll_colorBar.spn_preset.value																	-- Reload the current color scheme to apply the change in colors
						)
					)
				)
				
				
				-- Import new settings from external INI-file
				on btn_export pressed do
				(
					local f = getSaveFileName caption:"Select the path you want to export to:" filename:var_INIpath types:"INI-file (*.ini)|*.ini|All files (*.*)|*.*|"
					if f != undefined do																											-- Make sure the user didn't press cancel
					(
						deleteFile f																													-- Delete current copy of the file
						copyFile var_INIpath f																									-- Copy the current version
					)
				)
			) -- end roll_colorBarSettings
			
			createdialog roll_colorBarSettings width:210
			
		) -- end else
	) -- end fn_colorBarSettings

	
	
	-- ======================================================================================
	-- Main Rollout
	-- ======================================================================================
	
	
	rollout roll_colorBar "Color Bar"
	(
		spinner spn_preset across:11 range:[1,99,1] fieldwidth:22 pos:[5,5] type:#integer tooltip:"Change color swatches (1-15 is predefined)" on spn_preset changed value do
			fn_LoadPreset spn_preset.value
		
		colorpicker cp_1		color:[0,0,255] fieldWidth:35 height:20 align:#right on cp_1 changed color do
			fn_SavePreset cp_1.name cp_1.color
		colorpicker cp_2		color:[0,0,255] fieldWidth:35 height:20 align:#right on cp_2 changed color do
			fn_SavePreset cp_2.name cp_2.color
		colorpicker cp_3		color:[0,0,255] fieldWidth:35 height:20 align:#right on cp_3 changed color do
			fn_SavePreset cp_3.name cp_3.color
		colorpicker cp_4		color:[0,0,255] fieldWidth:35 height:20 align:#right on cp_4 changed color do
			fn_SavePreset cp_4.name cp_4.color
		colorpicker cp_5		color:[0,0,255] fieldWidth:35 height:20 align:#right on cp_5 changed color do
			fn_SavePreset cp_5.name cp_5.color
		colorpicker cp_6		color:[0,0,255] fieldWidth:35 height:20 align:#right on cp_6 changed color do
			fn_SavePreset cp_6.name cp_6.color
		colorpicker cp_7		color:[0,0,255] fieldWidth:35 height:20 align:#right on cp_7 changed color do
			fn_SavePreset cp_7.name cp_7.color
		colorpicker cp_8		color:[0,0,255] fieldWidth:35 height:20 align:#right on cp_8 changed color do
			fn_SavePreset cp_8.name cp_8.color
		colorpicker cp_9		color:[0,0,255] fieldWidth:35 height:20 align:#right on cp_9 changed color do
			fn_SavePreset cp_9.name cp_9.color
		colorpicker cp_10	color:[0,0,255] fieldWidth:35 height:20 align:#right on cp_10 changed color do
			fn_SavePreset cp_10.name cp_10.color
		
		
		button btn_settings "Set" across:11 height:12 width:31 pos:[8,25] tooltip:"Click: Settings\nCtrl+Click: Color Scheme Designer (web)\nAlt+Click: Randomize all colors" on btn_settings pressed do
			fn_colorBarSettings()
		
		button btn_wire1	height:7 width:35 tooltip:var_wireANDtooltip align:#right on btn_wire1 pressed do
			fn_WireAndRandomColor cp_1.name
		button btn_wire2	height:7 width:35 tooltip:var_wireANDtooltip align:#right on btn_wire2 pressed do
			fn_WireAndRandomColor cp_2.name
		button btn_wire3	height:7 width:35 tooltip:var_wireANDtooltip align:#right on btn_wire3 pressed do
			fn_WireAndRandomColor cp_3.name
		button btn_wire4	height:7 width:35 tooltip:var_wireANDtooltip align:#right on btn_wire4 pressed do
			fn_WireAndRandomColor cp_4.name
		button btn_wire5	height:7 width:35 tooltip:var_wireANDtooltip align:#right on btn_wire5 pressed do
			fn_WireAndRandomColor cp_5.name
		button btn_wire6	height:7 width:35 tooltip:var_wireANDtooltip align:#right on btn_wire6 pressed do
			fn_WireAndRandomColor cp_6.name
		button btn_wire7	height:7 width:35 tooltip:var_wireANDtooltip align:#right on btn_wire7 pressed do
			fn_WireAndRandomColor cp_7.name
		button btn_wire8	height:7 width:35 tooltip:var_wireANDtooltip align:#right on btn_wire8 pressed do
			fn_WireAndRandomColor cp_8.name
		button btn_wire9	height:7 width:35 tooltip:var_wireANDtooltip align:#right on btn_wire9 pressed do
			fn_WireAndRandomColor cp_9.name
		button btn_wire10	height:7 width:35 tooltip:var_wireANDtooltip align:#right on btn_wire10 pressed do
			fn_WireAndRandomColor cp_10.name
		
		
		-- Saves the current position when dialog is moved/closed
		on roll_colorBar moved pos do
		(
			setIniSetting var_INIpath "Dialog" "Position" (pos as string)
			try (setIniSetting var_INIpath "Dialog" "DockState" (cui.getDockState roll_colorBar)) catch ()
		)
		
		-- Load the saved colors when we run the script
		on roll_colorBar open do
		(
			roll_colorBar.spn_preset.value = (var_ActiveSwatch as integer)														-- Load last active color swatch
			fn_LoadPreset spn_preset.value																									-- Reload the current color scheme to apply the change in colors
		)
		
		-- Try to destroy the config dialog when shutting down
		on roll_colorBar close do
		(
			var_BarIsOpen = false
			updateToolbarButtons()
			
			try (destroydialog roll_colorBarSettings) catch()																			-- Try to close the settings dialog if open
			
			--setIniSetting var_INIpath "Dialog" "Position" (roll_colorBar.pos as string)
			try (setIniSetting var_INIpath "Dialog" "DockState" (cui.getDockState roll_colorBar)) catch ()
		)
	)
	
	
	-- Run through a checklist to assure the menu don't spawn outside the screen!
	if (var_LastPos == OK) or (var_LastPos == undefined) do var_LastPos = [-1,-1]
	if var_LastPos.x > (sysinfo.desktopSize.x - var_dialogWidth) do
	(
		var_LastPos.x = (sysinfo.desktopSize.x - var_dialogWidth)
		messagebox "The toolbar is currently located outside the width of your screen.\nAttempting to move it into the view!" title:"Error: ColorBar is located outside the screen!"
	)
	if var_LastPos.y > (sysinfo.desktopSize.y - var_dialogHeight) do
	(
		var_LastPos.y = (sysinfo.desktopSize.y - var_dialogHeight)
		messagebox "The toolbar is currently located outside the height of your screen.\nAttempting to move it into the view!" title:"Error: ColorBar is located outside the screen!"
	)

	
	createdialog roll_colorBar pos:var_LastPos width:var_dialogWidth height:var_dialogHeight
	cui.RegisterDialogBar roll_colorBar style:#(#cui_handles, #cui_dock_top, #cui_dock_bottom, #cui_floatable)	-- Register the dialog to a dialogBar so we can dock it
	
	
	-- Dock the color bar if needed
	if var_DockState == "cui_dock_left" do
		cui.dockDialogBar roll_colorBar #cui_dock_left
	if var_DockState == "cui_dock_right" do
		cui.dockDialogBar roll_colorBar #cui_dock_right
	if var_DockState == "cui_dock_top" do
		cui.dockDialogBar roll_colorBar #cui_dock_top
	if var_DockState == "cui_dock_bottom" do
		cui.dockDialogBar roll_colorBar #cui_dock_bottom
	
	
	/*
	on execute do
	(
		if var_BarIsOpen then --if open, close it
		(
			try (setIniSetting var_INIpath "Dialog" "DockState" (cui.getDockState roll_colorBar)) catch ()
			cui.unRegisterDialogBar roll_colorBar
			
			--setIniSetting var_INIpath "Dialog" "Position" (roll_colorBar.pos as string)
			destroydialog roll_colorBar
			--destroyDialog roll_colorBar
			
			var_BarIsOpen = false --and lower the flag
		)
		else --if closed, open it
		(
			print var_LastPos
			createdialog roll_colorBar width:450 pos:var_LastPos --height:450 --height:40
			cui.RegisterDialogBar roll_colorBar style:#(#cui_dock_top, #cui_dock_bottom, #cui_floatable,#cui_handles)				-- Register the dialog to a dialogBar so we can dock it
			
			if var_DockState == "cui_dock_left" do
				cui.dockDialogBar roll_colorBar #cui_dock_left
			if var_DockState == "cui_dock_right" do
				cui.dockDialogBar roll_colorBar #cui_dock_right
			if var_DockState == "cui_dock_top" do
				cui.dockDialogBar roll_colorBar #cui_dock_top
			if var_DockState == "cui_dock_bottom" do
				cui.dockDialogBar roll_colorBar #cui_dock_bottom
			
			--createDialog myRollout
			var_BarIsOpen = true --and raise the flag
		)
	)
	
	on isChecked return var_BarIsOpen --return the flag
	*/
	
) -- end script
